@@ -274,7 +274,7 @@ static const short compose_table[256] = {
   15 /* page 48 */
 };
 
-static const int compose_first_single[][2] = {
+static const unsigned long compose_first_single[][2] = {
  { 0x0338, 0x226e },
  { 0x0338, 0x2260 },
  { 0x0338, 0x226f },
@@ -486,7 +486,7 @@ static const int compose_first_single[][2] = {
  { 0x3099, 0x30fa },
  { 0x3099, 0x30fe }
 };
-static const int compose_second_single[][2] = {
+static const unsigned long compose_second_single[][2] = {
  { 0x0627, 0x0622 },
  { 0x0627, 0x0623 },
  { 0x0627, 0x0625 },
